@@ -11,7 +11,7 @@ class BaseConfig:
     Base class for configs you must inherit from if you want to write your own config class.
 
     """
-    def __init__(self, *args, __passed_classes: Set[Type] = None, **kwargs):
+    def __init__(self, *args, **kwargs):
         """
         Initializes config class.
 
@@ -23,10 +23,10 @@ class BaseConfig:
         self._loaders: Set[AbstractConfigLoader] = set()
         self._sub_configs: Set[BaseConfig] = set()
 
-        self.__init_variables_of_config(args, kwargs, __passed_classes)
+        self.__init_variables_of_config(args, kwargs)
         self.__post_init__(*args, **kwargs)
 
-    def __init_variables_of_config(self, args, kwargs, __passed_classes: Set[Type]):
+    def __init_variables_of_config(self, args, kwargs):
         for key in dir(self):
             obj = getattr(self, key, None)
 
@@ -37,16 +37,17 @@ class BaseConfig:
             if type(obj) is type and BaseConfig.__subclasscheck__(obj):
                 # initializing class with config underlying our main config
                 # here's fix for possible circular class initialization
-                if __passed_classes is None:
-                    __passed_classes = set()
+                if not hasattr(self, '__passed_classes'):
+                    self.__passed_classes = set()
 
-                __passed_classes.add(self.__class__)
-                if obj in __passed_classes:
+                self.__passed_classes.add(self.__class__)
+                if obj in self.__passed_classes:
                     # should fix recursive config classes referencing
                     continue
 
-                self.__dict__[key] = obj(*args, **kwargs, __passed_classes=__passed_classes)
-                self._sub_configs.add(self.__dict__[key])
+                new_config = obj(*args, **kwargs)
+                new_config.__passed_classes = self.__passed_classes
+                self.__dict__[key] = new_config
 
     def __post_init__(self, *args, **kwargs) -> NoReturn:
         """
